var group__PkgSpatialSearchingDConcepts =
[
    [ "FuzzyQueryItem", "classFuzzyQueryItem.html", [
      [ "Dimension", "classFuzzyQueryItem.html#abbf441d886fd0ab0bbacfb179bba7386", null ],
      [ "FT", "classFuzzyQueryItem.html#a01607a06d702dff55c32c55a764c15f2", null ],
      [ "Point_d", "classFuzzyQueryItem.html#ae1edf5aef303a1c5e0e4023c01563fa7", null ],
      [ "contains", "classFuzzyQueryItem.html#aca195968ba91ce339b920575d2ebd764", null ],
      [ "contains_point_given_as_coordinates", "classFuzzyQueryItem.html#ae49d6b5fa19ad45caa79088b52ece251", null ],
      [ "inner_range_intersects", "classFuzzyQueryItem.html#a7853c3abd8ebb57b2130ec2f4cbc902b", null ],
      [ "outer_range_contains", "classFuzzyQueryItem.html#ae412ce0829e7a765fc2f96eae8706ced", null ]
    ] ],
    [ "GeneralDistance", "classGeneralDistance.html", [
      [ "D", "classGeneralDistance.html#a185448eb9765d1eea6f7e3784ca93b17", null ],
      [ "FT", "classGeneralDistance.html#af4adc91845d58c4fae08bad19995e709", null ],
      [ "Point_d", "classGeneralDistance.html#a46434e72d556e98afcf2bc7191fdb101", null ],
      [ "Query_item", "classGeneralDistance.html#a786e3a3762a57c01f05631c5a8fdfa9c", null ],
      [ "interruptible_transformed_distance", "classGeneralDistance.html#a968f7878df3cb946b59dffa60a2d77d3", null ],
      [ "inverse_of_transformed_distance", "classGeneralDistance.html#a2e67e9e437ebc78ec43ca6496bdd11fb", null ],
      [ "max_distance_to_rectangle", "classGeneralDistance.html#af5c44719779fc5cc74529a2a87fd1e34", null ],
      [ "min_distance_to_rectangle", "classGeneralDistance.html#a8fb93296a1311a73feef25779a188e7d", null ],
      [ "transformed_distance", "classGeneralDistance.html#a8ac96d9b566a061ed621d663ccf18d5d", null ],
      [ "transformed_distance", "classGeneralDistance.html#a8d9da9dabde4dbbcd91f301f483e52d3", null ],
      [ "transformed_distance_from_coordinates", "classGeneralDistance.html#a137c26e6906ea27a14585d79496a10ed", null ]
    ] ],
    [ "OrthogonalDistance", "classOrthogonalDistance.html", [
      [ "D", "classOrthogonalDistance.html#addad553f7ca04bfff7354161a075973a", null ],
      [ "FT", "classOrthogonalDistance.html#ac02451a4b4d2743ddfbd6d092a371bee", null ],
      [ "Point_d", "classOrthogonalDistance.html#a0dc5450d7514bc5fa9decba9ed7f885c", null ],
      [ "Query_item", "classOrthogonalDistance.html#a11559bc19b225cc766cfb3569784cb5d", null ],
      [ "OrthogonalDistance", "classOrthogonalDistance.html#a6bb8a1db0683d77b484f4c567a0a1dff", null ],
      [ "inverse_of_transformed_distance", "classOrthogonalDistance.html#ac8900a1e20e50bfb22f983f7f1510cd0", null ],
      [ "max_distance_to_rectangle", "classOrthogonalDistance.html#ad49646d07b7ba7eff0d5f32be4132402", null ],
      [ "max_distance_to_rectangle", "classOrthogonalDistance.html#a493135f7404842bebb7abd9081346f34", null ],
      [ "min_distance_to_rectangle", "classOrthogonalDistance.html#a3a55df41a6c4fd493828982997e40ddc", null ],
      [ "min_distance_to_rectangle", "classOrthogonalDistance.html#a7915980d06cfaf7d22e45f27625bc929", null ],
      [ "new_distance", "classOrthogonalDistance.html#a299f707691fd6b809fd773ee8eeec1c5", null ],
      [ "transformed_distance", "classOrthogonalDistance.html#a2c36d684cf3b364957f2498446256d71", null ],
      [ "transformed_distance", "classOrthogonalDistance.html#a0837a53b3f5a6c62bf12e185df6e5d48", null ]
    ] ],
    [ "RangeSearchTraits", "classRangeSearchTraits.html", [
      [ "Compute_squared_radius_d", "classRangeSearchTraits.html#a32188071f8a063c1718f32b1842421f4", null ],
      [ "Construct_center_d", "classRangeSearchTraits.html#a86e8db6d2a14dbf25a9a9bf9ea8fb1c9", null ],
      [ "Construct_iso_box_d", "classRangeSearchTraits.html#aff830798bcf7837a8b83e10f82bf0c95", null ],
      [ "Construct_max_vertex_d", "classRangeSearchTraits.html#a641bc1fda0d1e75c2a45e78532a701c0", null ],
      [ "Construct_min_vertex_d", "classRangeSearchTraits.html#ae90f5b6bf93f51e12d702fc7befe6521", null ],
      [ "Iso_box_d", "classRangeSearchTraits.html#a3b91788e3b18f1fb721e66bd1af45475", null ],
      [ "Sphere_d", "classRangeSearchTraits.html#a800740b4d76de331bb356de7d2ecb280", null ]
    ] ],
    [ "SearchGeomTraits_2", "classSearchGeomTraits__2.html", [
      [ "Cartesian_const_iterator_2", "classSearchGeomTraits__2.html#a42d943953b1aab1cc82a106cef71d388", null ],
      [ "Circle_2", "classSearchGeomTraits__2.html#af6823e4a9eb1e725c2274e8c47d3a3d8", null ],
      [ "Compute_squared_radius_2", "classSearchGeomTraits__2.html#a5ac01098300631b50bf90d02d4a75230", null ],
      [ "Construct_cartesian_const_iterator_2", "classSearchGeomTraits__2.html#a6fe9882e9e81d72e7975f53483414524", null ],
      [ "Construct_center_2", "classSearchGeomTraits__2.html#a1a34050f83c0b3f4918b1b8a907a9f72", null ],
      [ "Construct_iso_rectangle_2", "classSearchGeomTraits__2.html#aad6de34302cf08eb8d99823c0899424b", null ],
      [ "Construct_max_vertex_2", "classSearchGeomTraits__2.html#a961128903169e9cbb47969d28a4d38ce", null ],
      [ "Construct_min_vertex_2", "classSearchGeomTraits__2.html#ac8af11e41bb12e1e86612d1f7416e5a1", null ],
      [ "FT", "classSearchGeomTraits__2.html#a7e0f8c0ee60dfad43d359ae34c2a02c6", null ],
      [ "Iso_rectangle_2", "classSearchGeomTraits__2.html#a1d3e3841645ef5def84840265c045b9f", null ],
      [ "Point_2", "classSearchGeomTraits__2.html#ae99e77c5e34685564757870e248c72ea", null ]
    ] ],
    [ "SearchGeomTraits_3", "classSearchGeomTraits__3.html", [
      [ "Cartesian_const_iterator_3", "classSearchGeomTraits__3.html#a13ada16e3c5f735974112337c6d2f706", null ],
      [ "Compute_squared_radius_3", "classSearchGeomTraits__3.html#a62171699d4f679a0902a1860c73b40d1", null ],
      [ "Construct_cartesian_const_iterator_3", "classSearchGeomTraits__3.html#a018410a5d903cbcac39cabb285848c2e", null ],
      [ "Construct_center_3", "classSearchGeomTraits__3.html#a5b8ec5844c61935ad4bc0c7f04c48e3f", null ],
      [ "Construct_iso_cuboid_3", "classSearchGeomTraits__3.html#a71e43ca33291eb8dad3e584f6a56ac8e", null ],
      [ "Construct_max_vertex_3", "classSearchGeomTraits__3.html#a1e3e7c52d92ddbbd6a068967fda29d75", null ],
      [ "Construct_min_vertex_3", "classSearchGeomTraits__3.html#a23e0a02dbcb01e2c690a9499a087d456", null ],
      [ "FT", "classSearchGeomTraits__3.html#a69268b7ed8ee0ecf894ba9813950d372", null ],
      [ "Iso_cuboid_3", "classSearchGeomTraits__3.html#a7523ffb6bea236f0ddca84e26bdf5049", null ],
      [ "Point_3", "classSearchGeomTraits__3.html#a7eab62efd01dbb63f1ff1b31f915153d", null ],
      [ "Sphere_3", "classSearchGeomTraits__3.html#a5edf0409af03de73996a7d842aa0f35c", null ]
    ] ],
    [ "SearchTraits", "classSearchTraits.html", [
      [ "Cartesian_const_iterator_d", "classSearchTraits.html#abb05f36835cece3db2694142a9f3acc6", null ],
      [ "Construct_cartesian_const_iterator_d", "classSearchTraits.html#a4cb34797407ff358ad2269a5cc14bb08", null ],
      [ "Dimension", "classSearchTraits.html#a0747aa4e30e20dd0a052d086e981ebe4", null ],
      [ "FT", "classSearchTraits.html#aa4641fbf5d2f1d4a55f2e7fa24c5da23", null ],
      [ "Point_d", "classSearchTraits.html#a6352b7ff783f425496c0b64757ad95bc", null ],
      [ "construct_cartesian_const_iterator_d_object", "classSearchTraits.html#a12fe10916a37b577aa606c08d5d11ba2", null ]
    ] ],
    [ "SpatialSeparator", "classSpatialSeparator.html", [
      [ "FT", "classSpatialSeparator.html#aa64bec7455d076dd8d23853280eef1d4", null ],
      [ "cutting_dimension", "classSpatialSeparator.html#aca343f2ab27a66712bc78bad81aa907e", null ],
      [ "cutting_value", "classSpatialSeparator.html#a1bf3ca3d327e7bc05291b1da4b57f69a", null ],
      [ "has_on_negative_side", "classSpatialSeparator.html#a37bd09a6d751cce967b7a02a640e582d", null ],
      [ "Separator", "classSpatialSeparator.html#a4d1b20941469566e0cf1b618562ea084", null ],
      [ "set_cutting_dimension", "classSpatialSeparator.html#a46a749d8cefa058df8972d110848890e", null ],
      [ "set_cutting_value", "classSpatialSeparator.html#a209785aba78499f4d4e5700cdd835198", null ]
    ] ],
    [ "SpatialTree", "classSpatialTree.html", [
      [ "D", "classSpatialTree.html#a53b678edfb91605cffc48f2960f4703c", null ],
      [ "Distance", "classSpatialTree.html#a2e307a0bed12cf298ef806ddb0107349", null ],
      [ "iterator", "classSpatialTree.html#af12392ac0084303869cc62c212fea05e", null ],
      [ "Node_const_handle", "classSpatialTree.html#a5de4fb6d964a1ac8e4b9a64680a1dcea", null ],
      [ "Node_handle", "classSpatialTree.html#a7a776d1dc487fd26c0d1d51afbebbbcd", null ],
      [ "Point_d", "classSpatialTree.html#a6f0770bfaa6fca692de08e190a938db0", null ],
      [ "Point_d_iterator", "classSpatialTree.html#a70b77e4abc63a67ae0f52beb254c4a97", null ],
      [ "SearchTraits", "classSpatialTree.html#a9b62c0abd63fbfa65bba51b4b7559bff", null ],
      [ "Splitter", "classSpatialTree.html#af22264cbaa002ab97ab19f7360ece798", null ],
      [ "begin", "classSpatialTree.html#a5e5ea5fa26f49324266bbeeb97216cfa", null ],
      [ "bounding_box", "classSpatialTree.html#a8b20cc6c3859203f7cd983dbb8529803", null ],
      [ "end", "classSpatialTree.html#a0395cb3d1d73239cd99cece1cf48d951", null ],
      [ "root", "classSpatialTree.html#acd0477e9268d2606b2b97846342d1221", null ],
      [ "root", "classSpatialTree.html#ac98d39f5a519606a71504a6b39294b89", null ],
      [ "search", "classSpatialTree.html#a64da78747580a1b1e30331b92fbf7182", null ],
      [ "size", "classSpatialTree.html#aec8a092ba0f76622a029303d8e2efc13", null ],
      [ "Tree", "classSpatialTree.html#aef5c2f7c04c551f3612dba40036a8df2", null ]
    ] ],
    [ "Splitter", "classSplitter.html", [
      [ "Container", "classSplitter.html#a53bef073a0821048228ae4b47af48e8d", null ],
      [ "FT", "classSplitter.html#ab42b210298bf7e781e325906045efc5b", null ],
      [ "Separator", "classSplitter.html#a4442d66ead8934322ccbad5ea28cc407", null ],
      [ "aspect_ratio", "classSplitter.html#a470899477d849a90577677c8edfc054a", null ],
      [ "bucket_size", "classSplitter.html#a43499be0f588da7f96b43885102af12f", null ],
      [ "operator()", "classSplitter.html#a4cf81c41d1c2bba18669f03ce55b7415", null ]
    ] ]
];